dsa API documentation
Description: dsa package for UC Berkeley Extension's Computer Science X404.1 Data Structures and Algorithms class …

# Package `dsa`

dsa package for UC Berkeley Extension's Computer Science X404.1 Data Structures and Algorithms class

Last Revision: 2/9/2025

## Sub-modules

`dsa.array`

  Module containing array classes.

`dsa.deque`

  Module containing deque classes.

`dsa.dijkstras`

  Module to access functions for Dijkstra's Algorithm.

`dsa.doublylinkedlist`

  Module containing doubly linked list class.

`dsa.draw`

  Module to access graphic drawing functions for Trees, Heaps, Tries and Graphs.

`dsa.graph`

  Module containing graph classes.

`dsa.hashtable`

  Module containing hash table class.

`dsa.heap`

  Module containing heap (max heap), min heap and priority queue classes.

`dsa.huffman`

  Module to access functions for Huffman Compression.

`dsa.pretty_print`

  Module to access functions for a clearer visual representation of certain data structures.

`dsa.prim`

  Module to access functions for Prim's Algorithm.

`dsa.queue`

  Module containing queue classes.

`dsa.singlylinkedlist`

  Module containing singly linked list class.

`dsa.sorttools`

  Module to access functions for sort benchmarking.

`dsa.stack`

  Module containing stack classes.

`dsa.tree`

  Module containing tree class.

`dsa.trie`

  Module containing trie class.